@@ -26,7 +26,7 @@ class NormalData(object):
         """
         normalize data_df to
                                     col1    col2    col3
-        entity_id    index_field
+        entity_id    timestamp
 
         """
         if pd_is_not_null(self.data_df):
