@@ -57,10 +57,10 @@ class EastmoneyChinaBlockStockRecorder(TimeSeriesDataRecorder):
     # 用于抓取行业包含的股票
     category_stocks_url = 'https://nufm.dfcfw.com/EM_Finance2014NumericApplication/JS.aspx?type=CT&cmd=C.{}{}&sty=SFCOO&st=(Close)&sr=-1&p=1&ps=300&cb=jsonp_B66B5BAA1C1B47B5BB9778045845B947&token=7bc05d0d4c3c22ef9fca8c2a912d779c'
 
-    def __init__(self, exchanges=None, entity_ids=None, codes=None, batch_size=10,
+    def __init__(self, exchanges=None, entity_ids=None, codes=None, day_data=False, batch_size=10,
                  force_update=False, sleeping_time=5, default_size=2000, real_time=False, fix_duplicate_way='add',
                  start_timestamp=None, end_timestamp=None, close_hour=0, close_minute=0) -> None:
-        super().__init__('block', exchanges, entity_ids, codes, batch_size, force_update, sleeping_time,
+        super().__init__('block', exchanges, entity_ids, codes, day_data, batch_size, force_update, sleeping_time,
                          default_size, real_time, fix_duplicate_way, start_timestamp, end_timestamp, close_hour,
                          close_minute)
 
